@@ -179,9 +179,8 @@ class ListEndpoint(object):
                                           viewFields=viewfields, 
                                           queryOptions=queryOptions, 
                                           rowLimit=1)
-
         if int(result.listitems.data._ItemCount) > 0:
-            return self._serializeListItem(result.listitems.data.row[0])
+            return self._serializeListItem(result.listitems.data.row)
         return []
 
     def deleteItems(self, *item_ids):
